/**
 * 图表配置相关的类型定义
 *
 * @author 海狸
 */
import { FieldType } from './dataPanel';
import { FieldModel } from './standard-model';
/**
 * 数值格式化配置
 */
export interface NumberFormat {
    /** 模式：默认为自动适配。0 自动适配；1 自定义模式；2 手工输入 */
    formatModal: '0' | '1' | '2';
    /**
     * 对应 原来为 serie.fmtType
     * formatModal = 0 (自动适配)下, 对应可取值为: CN 中文（默认） KMG 英文 CNT 繁体
     * formatModal = 1 (自定义模式)下, 对应可取值为: None
     * formatModal = 2 (手工输入)下, 对应可取值为: Custom
     */
    fmtType: 'CN' | 'KMG' | 'CNT' | 'Custom' | 'None';
    /** 值类型，默认为数值。0 数值；1 百分比 */
    valueModal: '0' | '1';
    /** 小数位，默认不选择。原来为 serie.decimalPlaces */
    decimalPlaces: '' | '0' | '1' | '2' | '3' | '4' | '5';
    /** 是否使用千分位分隔符，默认不使用。原来为 serie.thousandth */
    thousandth: boolean;
    /** 手工输入格式，原来为 serie.fmt */
    fmt: string;
    /** 数据单位 */
    magnitudeFormat?: number;
    /** 数据格式 */
    dataMagnitude?: string;
}
export declare enum SelectType {
    /** 自动 */
    'auto' = "auto",
    /** 整数 */
    'int' = "int",
    /** 保留1位小数 */
    'oneDecimal' = "oneDecimal",
    /** 保留2位小数 */
    'twoDecimal' = "twoDecimal",
    /** 百分比 */
    'percent' = "percent",
    /** 百分比1位小数 */
    'oneDecimalPercent' = "oneDecimalPercent",
    /** 百分比2位小数 */
    'twoDecimalPercent' = "twoDecimalPercent",
    /** 自定义 */
    'custom' = "custom"
}
export interface FieldNumberFormat extends NumberFormat {
    selectType?: SelectType;
    unit?: string;
}
export declare enum ImageDisplayMode {
    LEFT = 0,
    CENTER = 1,
    RIGHT = 2,
    CLIP = 3,
    STRETCH = 4
}
export declare enum LegendPositionType {
    /**
     * 不显示图例
     */
    None = "none",
    /**
     * 图例位于上部
     */
    Top = "top",
    /**
     * 图例位于底部
     */
    Bottom = "bottom",
    /**
     * 图例位于左侧
     */
    Left = "left",
    /**
     * 图例位于右侧
     */
    Right = "right"
}
/** 时间维度对应的环比同比字段
 * 日：昨日环比、上周同比、上月同比、去年同比，默认昨日环比，上周同比
 * 周: 上周环比、年同比，默认选择『上周环比』
 * 月：上月环比、年同比，默认选择『上月环比』
 * 季度：上季环比、年同比，默认选择『上季环比』
 * 年：年环比
 */
export declare const ConstastTypeMap: {
    dateRegion: string[];
    weekRegion: string[];
    monthRegion: string[];
    quarterRegion: string[];
    yearRegion: string[];
};
/**
 * 主题颜色配置
 */
export interface ThemeSeriesConfig {
    /** 自定义配色 */
    customColor: boolean;
    /** 颜色翻转 */
    flipColor: boolean;
    /** 颜色序列 */
    colors: string[];
    /** 自定义颜色类型 */
    customType: 'line' | 'range' | 'type';
    /** 配色模板的当前颜色主题 */
    theme: string;
    /** 配色的保存数据 */
    typeColors: {
        [key: string]: string;
    };
}
/**
 * 图表字段类型
 */
export declare enum ChartAreaType {
    /**
     * 度量轴
     */
    XAxis = "xAxis",
    /**
     * 通用y维度轴
     */
    YAxis = "yAxis",
    /**
     * 主值轴
     */
    YMainAxis = "yMainAxis",
    /**
     * 副值轴
     */
    YSecondaryAxis = "ySecondaryAxis",
    /**
     * 图例
     */
    Legend = "legend",
    /**
     * 行
     */
    Row = "row",
    /**
     * 列
     */
    Column = "column",
    /**
     * 图片
     */
    IMAGE = "image",
    /**
     * 辅助列
     */
    SecondaryColumn = "secondaryColumn"
}
/**
 * 图表系列设置，系列的类型
 */
export declare enum ChartSeriesType {
    /**
     * 度量
     */
    Measure = "measure",
    /**
     * 维度值
     */
    DimensionValue = "dimensionValue",
    /**
     * 组合类型，度量uuid + 维度值拼接
     */
    Combination = "combination"
}
/** 图表系列配置选项数据 */
export interface ChartSeriesOption {
    /** 作为字段时，对应的类型 */
    fieldType: FieldType;
    /** 系列类型 */
    seriesType: ChartSeriesType;
    /** 唯一id */
    uuid: string;
    /** 展示文案 */
    text: string;
    /** 对应的图例字段的唯一id */
    originalDimensionField?: FieldModel;
    /** 对应度量的唯一id */
    originalMeasureField?: FieldModel;
    /** 图例字段对应的维度值 */
    originalDimValue?: string;
}
/** 大屏中统一的文本样式配置 */
export interface ScreenTextStyle {
    /** 文字大小 */
    fontSize?: number;
    /** 文字颜色，可能为空 */
    fontColor?: string;
    /** 是否粗体 */
    bold?: boolean;
    /** 是否斜体 */
    italic?: boolean;
    /** 字体 */
    fontFamily?: string;
    /** 行高 */
    lineHeight?: number;
    /** 字间距 */
    letterSpacing?: number;
    /** 下划线 */
    underline?: boolean;
    /** 删除线 */
    strikethrough?: boolean;
}
/**
 * 大屏边框类型
 */
export declare enum ScreenBorderType {
    /** 上 */
    Top = "Top",
    /** 右 */
    Right = "Right",
    /** 下 */
    Bottom = "Bottom",
    /** 左 */
    Left = "Left",
    /** 全部 */
    All = "All"
}
/** 大屏中统一的背景样式配置 */
export interface ScreenBackgroundStyle {
    /** 背景颜色 */
    fillColor?: string;
    /** 开启背景填充 */
    enableFill?: boolean;
    /** 开启边框 */
    enableBorder?: boolean;
    /** 边框线的宽度 */
    borderWidth?: number;
    /** 边框线的类型 */
    borderType?: ScreenBorderType;
    /** 边框半径 */
    borderRadius?: number;
    /** 边框颜色 */
    borderColor?: string;
    /** 背景模糊大小 */
    blur?: number;
}
export interface ScreenLegendOption {
    /**
     * 是否开启
     */
    enable?: boolean;
    /**
     * 图例位置
     */
    position?: string;
    /**
     * 文本样式配置
     */
    textStyle?: ScreenTextStyle;
    /**
     * 选项间隙
     */
    itemGap?: number;
    /**
     * icon类型
     */
    itemSymbol?: string;
}
