/**
 * @author 雅影
 * @description 数据源类型定义
 */
/** 当前数据集来自的类型 */
export declare enum DsCreateOriginEnum {
    QUICKBI = 1,
    SYCM = 2,
    DING_TALK = 3,
    ASSET_PLATFORM = 4,
    /** qa 平台 */
    QA_PLATFORM = 5
}
/** 数据源类型定义 */
export interface DataSourceModel {
    /** 同实例判断依据 instance_key : md5(ds_type + host:port + user_name ) https://yuque.antfin-inc.com/quickbi/eg0h06/gr75bq */
    instanceKey: string;
    /** QuickEngine是否开启 */
    accelerationEngineOpen: boolean;
    dsId: string;
    apiDsId: string;
    /** 数据源类型 */
    dsType: DsType;
    showName: string;
    /** 数据源类型是否支持跨源join */
    supportAcrossJoin: boolean;
    /** 数据源类型是否支持自定义sql */
    supportCustomSql: boolean;
    /** 数据源类型是否支持文件 */
    supportFile: boolean;
    permissionList: string[];
    /** 数据库来源类型 */
    dsCreateOrigin: DsCreateOriginEnum;
    /** 是否支持quick 抽取 */
    supportQuickIndex: boolean;
    /** quickIndex 是否开启 */
    quickIndexOpen: boolean;
}
/** 数据源类型枚举 */
export declare enum DsType {
    /** 探索空间 */
    file = "file",
    clivia = "clivia",
    quickindex = "quickindex",
    api_datasource = "api_datasource",
    odps = "odps",
    maxcompute = "maxcompute",
    mysql = "mysql",
    mysql_hybrid = "mysql_hybrid",
    garuda = "garuda",
    sqlserver = "sqlserver",
    greenplum = "greenplum",
    ppas = "ppas",
    oracle = "oracle",
    postgresql = "postgresql",
    hive = "hive",
    vertica = "vertica",
    db2 = "db2",
    sybase = "sybase",
    hana = "hana",
    dla = "dla",
    oss = "oss",
    drds = "drds",
    presto = "presto",
    adb = "adb",
    polardb = "polardb",
    impala = "impala",
    multiDatasource = "multiDatasource",
    tsdb = "tsdb",
    hbase = "hbase",
    dataphin_odps = "dataphin_odps",
    dataphin_hive = "dataphin_hive",
    kbase = "kbase",
    clickhouse = "clickhouse",
    gbase = "gbase",
    polardb_pg = "polardb_pg",
    hologres = "hologres",
    teradata = "teradata",
    spark_sql = "spark_sql",
    dingtalk = "dingtalk",
    analyticdb_v3 = "analyticdb_v3"
}
export declare enum AcrossDsType {
    UN_SET,
    /** 无跨源 */
    NU_ACROSS = 0,
    /** 同实例跨源 */
    SAME_INSTANCE_ACROSS = 1,
    /** 非同实例跨源 */
    DIFF_INSTANCE_ACROSS = 2
}
/** 数据集跨源模式 */
export declare enum DataLoadMode {
    /** 非抽取跨源 */
    Default = 0,
    /** 抽取跨源 */
    QuickIndex = 1
}
